==> mule-maven-pom-parser-impl-2.6.0-20250812.234307-6-test-sources.jar: org/mule/maven/pom/parser/internal/MavenPomParserImplTestCase.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.maven.pom.parser.internal;

import static org.mule.maven.pom.parser.internal.AllureConstants.MavenParserClient.MAVEN_PARSER_CLIENT;
import static org.mule.maven.pom.parser.internal.AllureConstants.MavenParserClient.PomParsingStory.MAVEN_POM_PARSING_STORY;
import static org.mule.maven.pom.parser.internal.util.TestUtils.getPath;

import static java.util.stream.Collectors.toList;

import static org.hamcrest.CoreMatchers.is;
import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.allOf;
import static org.hamcrest.Matchers.containsInAnyOrder;
import static org.hamcrest.Matchers.empty;
import static org.hamcrest.Matchers.hasItems;
import static org.hamcrest.Matchers.hasProperty;
import static org.hamcrest.Matchers.hasSize;

import org.mule.maven.pom.parser.api.MavenPomParser;
import org.mule.maven.pom.parser.api.model.AdditionalPluginDependencies;
import org.mule.maven.pom.parser.api.model.BundleDependency;
import org.mule.maven.pom.parser.api.model.BundleDescriptor;
import org.mule.maven.pom.parser.api.model.SharedLibrary;

import java.util.Collection;
import java.util.LinkedList;
import java.util.List;

import org.junit.Test;

import io.qameta.allure.Feature;
import io.qameta.allure.Issue;
import io.qameta.allure.Story;

@Feature(MAVEN_PARSER_CLIENT)
@Story(MAVEN_POM_PARSING_STORY)
public class MavenPomParserImplTestCase {

  private final static String BASIC_WITH_RESOURCES_POM = "basic-with-resources/pom.xml";
  private final static String BASIC_WITH_DIFFERENT_SOURCE_DIRECTORY_POM = "basic-with-different-source-directory/pom.xml";
  private final static String BASIC_POM = "basic/pom.xml";
  private final static String BASIC_DEP_WITH_EMPTY_SCOPES_POM = "basic-dep-with-empty-scope/pom.xml";
  private final static String SHARE_LIB_POM = "shared-lib/pom.xml";
  private final static String ADDITIONAL_DEPENDENCIES_POM = "additional-plugin-dependency/pom.xml";
  private final static String ADDITIONAL_DEPENDENCIES_SYSTEM_PROPERTY_POM =
      "additional-plugin-dependency-system-property/pom.xml";
  private final static String ADDITIONAL_DEPENDENCIES_PROPERTY_POM =
      "additional-plugin-dependency-property/pom.xml";
  private final static String BASIC_WITH_SHADE_PLUGIN_POM = "basic-with-shade-plugin/pom.xml";

  @Test
  public void getSourceDirectoryWhenNotPresentTestCase() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(BASIC_POM));
    assertThat(mavenPomParser.getSourceDirectory(), is(MavenPomParserImpl.DEFAULT_SOURCES_DIRECTORY));
  }

  @Test
  @Issue("W-15677833")
  public void getCompileDependenciesWithEmptyScope() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(BASIC_DEP_WITH_EMPTY_SCOPES_POM));
    final List<BundleDependency> noScopeDeps = mavenPomParser.getDependencies().stream()
        .filter(dep -> dep.getScope() == null)
        .collect(toList());

    assertThat(noScopeDeps, hasSize(2));
  }

  @Test
  public void getSourceDirectoryWhenPresentTestCase() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(BASIC_WITH_DIFFERENT_SOURCE_DIRECTORY_POM));
    assertThat(mavenPomParser.getSourceDirectory(), is("src/main2"));
  }

  @Test
  public void getResourceDirectoryWhenPresentTestCase() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(BASIC_WITH_RESOURCES_POM));
    List<String> resourceDirectories = mavenPomParser.getResourceDirectories();
    assertThat(resourceDirectories, hasSize(2));
    assertThat(resourceDirectories, containsInAnyOrder("src/main/resources", "src/main/resources2"));
  }

  @Test
  public void getResourceDirectoryWhenNotPresentTestCase() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(BASIC_POM));
    assertThat(mavenPomParser.getResourceDirectories(), is(empty()));
  }

  @Test
  public void getSharedLibrariesTestCase() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(SHARE_LIB_POM));
    List<SharedLibrary> sharedLibraries = mavenPomParser.getSharedLibraries();
    assertThat(sharedLibraries, hasSize(1));
    SharedLibrary sharedLibrary = sharedLibraries.get(0);
    assertThat(sharedLibrary.getGroupId(), is("org.apache.derby"));
    assertThat(sharedLibrary.getArtifactId(), is("derby"));
  }

  @Test
  public void getDependencies() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(BASIC_POM));
    List<BundleDependency> dependencies = mavenPomParser.getDependencies();
    assertThat(dependencies, hasSize(3));
    List<BundleDescriptor> descriptors = dependencies.stream().map(BundleDependency::getDescriptor).collect(toList());
    assertThat(descriptors, hasItems(
                                     allOf(hasProperty("groupId", is("org.mule.connectors")),
                                           hasProperty("artifactId", is("mule-http-connector")),
                                           hasProperty("version", is("1.1.0"))),
                                     allOf(hasProperty("groupId", is("org.mule.connectors")),
                                           hasProperty("artifactId", is("mule-db-connector")),
                                           hasProperty("version", is("1.13.1"))),
                                     allOf(hasProperty("groupId", is("org.mule.connectors")),
                                           hasProperty("artifactId", is("mule-jms-connector")),
                                           hasProperty("version", is("1.8.4")))));
  }

  @Test
  public void getSharedLibrariesWhenNotPresentTestCase() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(BASIC_POM));
    List<SharedLibrary> sharedLibraries = mavenPomParser.getSharedLibraries();
    assertThat(sharedLibraries, hasSize(0));
  }

  @Test
  public void getPomAdditionalDependenciesTestCase() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(ADDITIONAL_DEPENDENCIES_POM));
    List<AdditionalPluginDependencies> artifactsAdditionalDependencies =
        new LinkedList<>(mavenPomParser.getPomAdditionalPluginDependenciesForArtifacts().values());
    assertThat(artifactsAdditionalDependencies, hasSize(1));
    AdditionalPluginDependencies mavenPluginAdditionalDependencies = artifactsAdditionalDependencies.get(0);
    assertThat(mavenPluginAdditionalDependencies.getGroupId(), is("org.mule.connectors"));
    assertThat(mavenPluginAdditionalDependencies.getArtifactId(), is("mule-db-connector"));
    List<BundleDescriptor> additionalDependencies = mavenPluginAdditionalDependencies.getAdditionalDependencies();
    assertThat(additionalDependencies, hasSize(1));
    BundleDescriptor bundleDescriptor = additionalDependencies.get(0);
    assertThat(bundleDescriptor.getGroupId(), is("org.apache.derby"));
    assertThat(bundleDescriptor.getArtifactId(), is("derby"));
    assertThat(bundleDescriptor.getVersion(), is("10.14.2.0"));
  }

  @Test
  public void getPomAdditionalDependenciesSystemPropertyTestCase() {
    System.setProperty("derbyVersion", "10.14.2.0");

    try {
      MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(ADDITIONAL_DEPENDENCIES_SYSTEM_PROPERTY_POM));
      List<AdditionalPluginDependencies> artifactsAdditionalDependencies =
          new LinkedList<>(mavenPomParser.getPomAdditionalPluginDependenciesForArtifacts().values());
      assertThat(artifactsAdditionalDependencies, hasSize(1));
      AdditionalPluginDependencies mavenPluginAdditionalDependencies = artifactsAdditionalDependencies.get(0);
      assertThat(mavenPluginAdditionalDependencies.getGroupId(), is("org.mule.connectors"));
      assertThat(mavenPluginAdditionalDependencies.getArtifactId(), is("mule-db-connector"));
      List<BundleDescriptor> additionalDependencies = mavenPluginAdditionalDependencies.getAdditionalDependencies();
      assertThat(additionalDependencies, hasSize(1));
      BundleDescriptor bundleDescriptor = additionalDependencies.get(0);
      assertThat(bundleDescriptor.getGroupId(), is("org.apache.derby"));
      assertThat(bundleDescriptor.getArtifactId(), is("derby"));
      assertThat(bundleDescriptor.getVersion(), is("10.14.2.0"));
    } finally {
      System.clearProperty("derbyVersion");
    }
  }

  @Test
  @Issue("W-16190426")
  public void getPomAdditionalDependenciesPropertyTestCase() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(ADDITIONAL_DEPENDENCIES_PROPERTY_POM));
    List<AdditionalPluginDependencies> artifactsAdditionalDependencies =
        new LinkedList<>(mavenPomParser.getPomAdditionalPluginDependenciesForArtifacts().values());
    assertThat(artifactsAdditionalDependencies, hasSize(1));
    AdditionalPluginDependencies mavenPluginAdditionalDependencies = artifactsAdditionalDependencies.get(0);
    assertThat(mavenPluginAdditionalDependencies.getGroupId(), is("org.mule.connectors"));
    assertThat(mavenPluginAdditionalDependencies.getArtifactId(), is("mule-db-connector"));
    List<BundleDescriptor> additionalDependencies = mavenPluginAdditionalDependencies.getAdditionalDependencies();
    assertThat(additionalDependencies, hasSize(1));
    BundleDescriptor bundleDescriptor = additionalDependencies.get(0);
    assertThat(bundleDescriptor.getGroupId(), is("org.apache.derby"));
    assertThat(bundleDescriptor.getArtifactId(), is("derby"));
    assertThat(bundleDescriptor.getVersion(), is("10.14.2.0"));
  }

  @Test
  public void getPomAdditionalDependenciesPropertyPrecedenceTestCase() {
    System.setProperty("derbyVersion", "10.15.1.3");

    try {
      MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(ADDITIONAL_DEPENDENCIES_PROPERTY_POM));
      List<AdditionalPluginDependencies> artifactsAdditionalDependencies =
          new LinkedList<>(mavenPomParser.getPomAdditionalPluginDependenciesForArtifacts().values());
      assertThat(artifactsAdditionalDependencies, hasSize(1));
      AdditionalPluginDependencies mavenPluginAdditionalDependencies = artifactsAdditionalDependencies.get(0);
      assertThat(mavenPluginAdditionalDependencies.getGroupId(), is("org.mule.connectors"));
      assertThat(mavenPluginAdditionalDependencies.getArtifactId(), is("mule-db-connector"));
      List<BundleDescriptor> additionalDependencies = mavenPluginAdditionalDependencies.getAdditionalDependencies();
      assertThat(additionalDependencies, hasSize(1));
      BundleDescriptor bundleDescriptor = additionalDependencies.get(0);
      assertThat(bundleDescriptor.getGroupId(), is("org.apache.derby"));
      assertThat(bundleDescriptor.getArtifactId(), is("derby"));
      // system property overrides the one defined in the pom
      assertThat(bundleDescriptor.getVersion(), is("10.15.1.3"));
    } finally {
      System.clearProperty("derbyVersion");
    }
  }

  @Test
  public void getPomAdditionalDependenciesWhenNotPresentTestCase() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(BASIC_POM));
    Collection<AdditionalPluginDependencies> artifactsAdditionalDependencies =
        mavenPomParser.getPomAdditionalPluginDependenciesForArtifacts().values();
    assertThat(artifactsAdditionalDependencies, hasSize(0));
  }

  @Test
  public void isShadePluginConfiguredTestCase() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(BASIC_POM));
    assertThat(mavenPomParser.isMavenShadePluginConfigured(), is(false));

    mavenPomParser = new MavenPomParserImpl(getPath(BASIC_WITH_SHADE_PLUGIN_POM));
    assertThat(mavenPomParser.isMavenShadePluginConfigured(), is(true));
  }
}

==> mule-maven-pom-parser-impl-2.6.0-20251013.195348-10-test-sources.jar: org/mule/maven/pom/parser/internal/MavenPomParserImplTestCase.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.maven.pom.parser.internal;

import static org.mule.maven.pom.parser.internal.AllureConstants.MavenParserClient.MAVEN_PARSER_CLIENT;
import static org.mule.maven.pom.parser.internal.AllureConstants.MavenParserClient.PomParsingStory.MAVEN_POM_PARSING_STORY;
import static org.mule.maven.pom.parser.internal.util.TestUtils.getPath;

import static java.util.stream.Collectors.toList;

import static org.hamcrest.CoreMatchers.is;
import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.allOf;
import static org.hamcrest.Matchers.containsInAnyOrder;
import static org.hamcrest.Matchers.empty;
import static org.hamcrest.Matchers.hasItems;
import static org.hamcrest.Matchers.hasProperty;
import static org.hamcrest.Matchers.hasSize;

import org.mule.maven.pom.parser.api.MavenPomParser;
import org.mule.maven.pom.parser.api.model.AdditionalPluginDependencies;
import org.mule.maven.pom.parser.api.model.BundleDependency;
import org.mule.maven.pom.parser.api.model.BundleDescriptor;
import org.mule.maven.pom.parser.api.model.SharedLibrary;

import java.util.Collection;
import java.util.LinkedList;
import java.util.List;

import org.junit.Test;

import io.qameta.allure.Feature;
import io.qameta.allure.Issue;
import io.qameta.allure.Story;

@Feature(MAVEN_PARSER_CLIENT)
@Story(MAVEN_POM_PARSING_STORY)
public class MavenPomParserImplTestCase {

  private final static String BASIC_WITH_RESOURCES_POM = "basic-with-resources/pom.xml";
  private final static String BASIC_WITH_DIFFERENT_SOURCE_DIRECTORY_POM = "basic-with-different-source-directory/pom.xml";
  private final static String BASIC_POM = "basic/pom.xml";
  private final static String BASIC_NO_BUILD_POM = "basic-no-build/pom.xml";
  private final static String BASIC_DEP_WITH_EMPTY_SCOPES_POM = "basic-dep-with-empty-scope/pom.xml";
  private final static String SHARE_LIB_POM = "shared-lib/pom.xml";
  private final static String ADDITIONAL_DEPENDENCIES_POM = "additional-plugin-dependency/pom.xml";
  private final static String ADDITIONAL_DEPENDENCIES_SYSTEM_PROPERTY_POM =
      "additional-plugin-dependency-system-property/pom.xml";
  private final static String ADDITIONAL_DEPENDENCIES_PROPERTY_POM =
      "additional-plugin-dependency-property/pom.xml";
  private final static String BASIC_WITH_SHADE_PLUGIN_POM = "basic-with-shade-plugin/pom.xml";

  @Test
  public void getSourceDirectoryWhenNotPresent() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(BASIC_POM));
    assertThat(mavenPomParser.getSourceDirectory(), is(MavenPomParserImpl.DEFAULT_SOURCES_DIRECTORY));
  }

  @Test
  public void getSourceDirectoryWhenNoBuildSection() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(BASIC_NO_BUILD_POM));
    assertThat(mavenPomParser.getSourceDirectory(), is(MavenPomParserImpl.DEFAULT_SOURCES_DIRECTORY));
  }

  @Test
  @Issue("W-15677833")
  public void getCompileDependenciesWithEmptyScope() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(BASIC_DEP_WITH_EMPTY_SCOPES_POM));
    final List<BundleDependency> noScopeDeps = mavenPomParser.getDependencies().stream()
        .filter(dep -> dep.getScope() == null)
        .collect(toList());

    assertThat(noScopeDeps, hasSize(2));
  }

  @Test
  public void getSourceDirectoryWhenPresent() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(BASIC_WITH_DIFFERENT_SOURCE_DIRECTORY_POM));
    assertThat(mavenPomParser.getSourceDirectory(), is("src/main2"));
  }

  @Test
  public void getResourceDirectoryWhenPresent() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(BASIC_WITH_RESOURCES_POM));
    List<String> resourceDirectories = mavenPomParser.getResourceDirectories();
    assertThat(resourceDirectories, hasSize(2));
    assertThat(resourceDirectories, containsInAnyOrder("src/main/resources", "src/main/resources2"));
  }

  @Test
  public void getResourceDirectoryWhenNotPresent() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(BASIC_POM));
    assertThat(mavenPomParser.getResourceDirectories(), is(empty()));
  }

  @Test
  public void getResourceDirectoryWhenNoBuildSection() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(BASIC_NO_BUILD_POM));
    assertThat(mavenPomParser.getResourceDirectories(), is(empty()));
  }

  @Test
  public void getSharedLibraries() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(SHARE_LIB_POM));
    List<SharedLibrary> sharedLibraries = mavenPomParser.getSharedLibraries();
    assertThat(sharedLibraries, hasSize(1));
    SharedLibrary sharedLibrary = sharedLibraries.get(0);
    assertThat(sharedLibrary.getGroupId(), is("org.apache.derby"));
    assertThat(sharedLibrary.getArtifactId(), is("derby"));
  }

  @Test
  public void getDependencies() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(BASIC_POM));
    List<BundleDependency> dependencies = mavenPomParser.getDependencies();
    assertThat(dependencies, hasSize(3));
    List<BundleDescriptor> descriptors = dependencies.stream().map(BundleDependency::getDescriptor).collect(toList());
    assertThat(descriptors, hasItems(
                                     allOf(hasProperty("groupId", is("org.mule.connectors")),
                                           hasProperty("artifactId", is("mule-http-connector")),
                                           hasProperty("version", is("1.1.0"))),
                                     allOf(hasProperty("groupId", is("org.mule.connectors")),
                                           hasProperty("artifactId", is("mule-db-connector")),
                                           hasProperty("version", is("1.13.1"))),
                                     allOf(hasProperty("groupId", is("org.mule.connectors")),
                                           hasProperty("artifactId", is("mule-jms-connector")),
                                           hasProperty("version", is("1.8.4")))));
  }

  @Test
  public void getSharedLibrariesWhenNotPresent() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(BASIC_POM));
    List<SharedLibrary> sharedLibraries = mavenPomParser.getSharedLibraries();
    assertThat(sharedLibraries, hasSize(0));
  }

  @Test
  public void getPomAdditionalDependencies() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(ADDITIONAL_DEPENDENCIES_POM));
    List<AdditionalPluginDependencies> artifactsAdditionalDependencies =
        new LinkedList<>(mavenPomParser.getPomAdditionalPluginDependenciesForArtifacts().values());
    assertThat(artifactsAdditionalDependencies, hasSize(1));
    AdditionalPluginDependencies mavenPluginAdditionalDependencies = artifactsAdditionalDependencies.get(0);
    assertThat(mavenPluginAdditionalDependencies.getGroupId(), is("org.mule.connectors"));
    assertThat(mavenPluginAdditionalDependencies.getArtifactId(), is("mule-db-connector"));
    List<BundleDescriptor> additionalDependencies = mavenPluginAdditionalDependencies.getAdditionalDependencies();
    assertThat(additionalDependencies, hasSize(1));
    BundleDescriptor bundleDescriptor = additionalDependencies.get(0);
    assertThat(bundleDescriptor.getGroupId(), is("org.apache.derby"));
    assertThat(bundleDescriptor.getArtifactId(), is("derby"));
    assertThat(bundleDescriptor.getVersion(), is("10.14.2.0"));
  }

  @Test
  public void getPomAdditionalDependenciesSystemPropertyTestCase() {
    System.setProperty("derbyVersion", "10.14.2.0");

    try {
      MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(ADDITIONAL_DEPENDENCIES_SYSTEM_PROPERTY_POM));
      List<AdditionalPluginDependencies> artifactsAdditionalDependencies =
          new LinkedList<>(mavenPomParser.getPomAdditionalPluginDependenciesForArtifacts().values());
      assertThat(artifactsAdditionalDependencies, hasSize(1));
      AdditionalPluginDependencies mavenPluginAdditionalDependencies = artifactsAdditionalDependencies.get(0);
      assertThat(mavenPluginAdditionalDependencies.getGroupId(), is("org.mule.connectors"));
      assertThat(mavenPluginAdditionalDependencies.getArtifactId(), is("mule-db-connector"));
      List<BundleDescriptor> additionalDependencies = mavenPluginAdditionalDependencies.getAdditionalDependencies();
      assertThat(additionalDependencies, hasSize(1));
      BundleDescriptor bundleDescriptor = additionalDependencies.get(0);
      assertThat(bundleDescriptor.getGroupId(), is("org.apache.derby"));
      assertThat(bundleDescriptor.getArtifactId(), is("derby"));
      assertThat(bundleDescriptor.getVersion(), is("10.14.2.0"));
    } finally {
      System.clearProperty("derbyVersion");
    }
  }

  @Test
  @Issue("W-16190426")
  public void getPomAdditionalDependenciesProperty() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(ADDITIONAL_DEPENDENCIES_PROPERTY_POM));
    List<AdditionalPluginDependencies> artifactsAdditionalDependencies =
        new LinkedList<>(mavenPomParser.getPomAdditionalPluginDependenciesForArtifacts().values());
    assertThat(artifactsAdditionalDependencies, hasSize(1));
    AdditionalPluginDependencies mavenPluginAdditionalDependencies = artifactsAdditionalDependencies.get(0);
    assertThat(mavenPluginAdditionalDependencies.getGroupId(), is("org.mule.connectors"));
    assertThat(mavenPluginAdditionalDependencies.getArtifactId(), is("mule-db-connector"));
    List<BundleDescriptor> additionalDependencies = mavenPluginAdditionalDependencies.getAdditionalDependencies();
    assertThat(additionalDependencies, hasSize(1));
    BundleDescriptor bundleDescriptor = additionalDependencies.get(0);
    assertThat(bundleDescriptor.getGroupId(), is("org.apache.derby"));
    assertThat(bundleDescriptor.getArtifactId(), is("derby"));
    assertThat(bundleDescriptor.getVersion(), is("10.14.2.0"));
  }

  @Test
  public void getPomAdditionalDependenciesPropertyPrecedenceTestCase() {
    System.setProperty("derbyVersion", "10.15.1.3");

    try {
      MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(ADDITIONAL_DEPENDENCIES_PROPERTY_POM));
      List<AdditionalPluginDependencies> artifactsAdditionalDependencies =
          new LinkedList<>(mavenPomParser.getPomAdditionalPluginDependenciesForArtifacts().values());
      assertThat(artifactsAdditionalDependencies, hasSize(1));
      AdditionalPluginDependencies mavenPluginAdditionalDependencies = artifactsAdditionalDependencies.get(0);
      assertThat(mavenPluginAdditionalDependencies.getGroupId(), is("org.mule.connectors"));
      assertThat(mavenPluginAdditionalDependencies.getArtifactId(), is("mule-db-connector"));
      List<BundleDescriptor> additionalDependencies = mavenPluginAdditionalDependencies.getAdditionalDependencies();
      assertThat(additionalDependencies, hasSize(1));
      BundleDescriptor bundleDescriptor = additionalDependencies.get(0);
      assertThat(bundleDescriptor.getGroupId(), is("org.apache.derby"));
      assertThat(bundleDescriptor.getArtifactId(), is("derby"));
      // system property overrides the one defined in the pom
      assertThat(bundleDescriptor.getVersion(), is("10.15.1.3"));
    } finally {
      System.clearProperty("derbyVersion");
    }
  }

  @Test
  public void getPomAdditionalDependenciesWhenNotPresent() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(BASIC_POM));
    Collection<AdditionalPluginDependencies> artifactsAdditionalDependencies =
        mavenPomParser.getPomAdditionalPluginDependenciesForArtifacts().values();
    assertThat(artifactsAdditionalDependencies, hasSize(0));
  }

  @Test
  public void isShadePluginConfigured() {
    MavenPomParser mavenPomParser = new MavenPomParserImpl(getPath(BASIC_POM));
    assertThat(mavenPomParser.isMavenShadePluginConfigured(), is(false));

    mavenPomParser = new MavenPomParserImpl(getPath(BASIC_WITH_SHADE_PLUGIN_POM));
    assertThat(mavenPomParser.isMavenShadePluginConfigured(), is(true));
  }
}
